==> WebCore-85.5.tar.gz: WebCore-85.5/kwq/KWQDictImpl.mm <==
/*
 * Copyright (C) 2003 Apple Computer, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE COMPUTER, INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE COMPUTER, INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#import "KWQDictImpl.h"
#import <CoreFoundation/CoreFoundation.h>

KWQDictImpl::KWQDictImpl(int size, bool caseSensitive, void (*deleteFunc)(void *)) :
    KWQPtrDictImpl(size, deleteFunc, &kCFCopyStringDictionaryKeyCallBacks)
{
}

void KWQDictImpl::insert(const QString &key, const void *value)
{
    KWQPtrDictImpl::insert((void *)key.getCFString(), value);
}

bool KWQDictImpl::remove(const QString &key, bool deleteItem)
{
    return KWQPtrDictImpl::remove((void *)key.getCFString(), deleteItem);
}

void *KWQDictImpl::find(const QString &key) const
{
    return KWQPtrDictImpl::find((void *)key.getCFString());
}

QString KWQDictIteratorImpl::currentStringKey() const
{
    void *key = currentKey();

    if (key == NULL) {
	return QString();
    }
    return QString::fromCFString((CFStringRef)key);
}

==> WebCore-415.5.tar.gz: WebCore-415.5/kwq/KWQDictImpl.mm <==
/*
 * Copyright (C) 2003 Apple Computer, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE COMPUTER, INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE COMPUTER, INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#import "KWQDictImpl.h"
#import <CoreFoundation/CoreFoundation.h>

KWQDictImpl::KWQDictImpl(int size, bool caseSensitive, void (*deleteFunc)(void *)) :
    KWQPtrDictImpl(size, deleteFunc, &kCFCopyStringDictionaryKeyCallBacks), m_caseSensitive(caseSensitive)
{
}

void KWQDictImpl::insert(const QString &key, const void *value)
{
    KWQPtrDictImpl::insert((void *)(m_caseSensitive ? key : key.lower()).getCFString(), value);
}

bool KWQDictImpl::remove(const QString &key, bool deleteItem)
{
    return KWQPtrDictImpl::remove((void *)(m_caseSensitive ? key : key.lower()).getCFString(), deleteItem);
}

void *KWQDictImpl::find(const QString &key) const
{
    return KWQPtrDictImpl::find((void *)(m_caseSensitive ? key : key.lower()).getCFString());
}

QString KWQDictIteratorImpl::currentStringKey() const
{
    void *key = currentKey();

    if (key == NULL)
        return QString();
        
    return QString::fromCFString((CFStringRef)key);
}
